jacinle.cli.keyboard
====================

.. automodule:: jacinle.cli.keyboard

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      maybe_mkdir
      str2bool
      str2bool_long
      yes_or_no
      yn2bool
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: maybe_mkdir

.. autofunction:: str2bool

.. autofunction:: str2bool_long

.. autofunction:: yes_or_no

.. autofunction:: yn2bool


